@@ -105,7 +105,7 @@ class GenericCommandParametersModel(JadeBaseModel):
         title="name",
         description="If not set Jade will use the job_id converted to a string. Must be unique.",
     )
-    use_multi_node_manager: Optional[bool] = Field(
+    use_multi_node_manager: bool = Field(
         title="use_multi_node_manager",
         description="If true JADE will run this job with its multi-node manager.",
         default=False,
@@ -119,12 +119,12 @@ class GenericCommandParametersModel(JadeBaseModel):
         title="command",
         description="Command that can be invoked in a terminal (shell characters not allowed)",
     )
-    blocked_by: Optional[Set[str]] = Field(
+    blocked_by: Set[str] = Field(
         title="blocked_by",
         description="Array of job names that must complete before this one can start.",
         default=set(),
     )
-    cancel_on_blocking_job_failure: Optional[bool] = Field(
+    cancel_on_blocking_job_failure: bool = Field(
         title="cancel_on_blocking_job_failure",
         description="If true JADE will cancel this job if any of its blocking jobs fail.",
         default=False,
@@ -134,18 +134,18 @@ class GenericCommandParametersModel(JadeBaseModel):
         description="JADE will use this value along with num-processes and walltime to "
         "build per-node batches of jobs if time-based-batching is enabled.",
     )
-    submission_group: Optional[str] = Field(
+    submission_group: str = Field(
         title="submission_group",
         description="Optional name of a submission group",
         default=DEFAULT_SUBMISSION_GROUP,
     )
-    append_output_dir: Optional[bool] = Field(
+    append_output_dir: bool = Field(
         title="append_output_dir",
         description="If true JADE will append --jade-runtime-output=X where X is the output "
         "directory specified in jade submit-jobs.",
         default=False,
     )
-    ext: Optional[Dict] = Field(
+    ext: Dict = Field(
         title="ext",
         description="User-defined extension data to be used at runtime. Must be serializable in "
         "JSON format.",
@@ -155,7 +155,7 @@ class GenericCommandParametersModel(JadeBaseModel):
         title="job_id",
         description="Unique job identifier, generated by JADE",
     )
-    extension: Optional[str] = Field(
+    extension: str = Field(
         title="extension",
         description="job extension type, generated by JADE",
         default=_EXTENSION,
